package com.dcs.hnyz.mapper;

import java.util.List;
import com.dcs.hnyz.domain.DcsRequestTask;
import org.apache.ibatis.annotations.Mapper;

/**
 * 请求任务Mapper接口
 *
 * @author wuhb
 * @date 2025-08-02
 */
@Mapper
public interface DcsRequestTaskMapper
{
    /**
     * 查询请求任务
     *
     * @param requestId 请求任务主键
     * @return 请求任务
     */
    public DcsRequestTask selectDcsRequestTaskByRequestId(Long requestId);

    /**
     * 查询请求任务列表
     *
     * @param dcsRequestTask 请求任务
     * @return 请求任务集合
     */
    public List<DcsRequestTask> selectDcsRequestTaskList(DcsRequestTask dcsRequestTask);

    /**
     * 新增请求任务
     *
     * @param dcsRequestTask 请求任务
     * @return 结果
     */
    public int insertDcsRequestTask(DcsRequestTask dcsRequestTask);

    /**
     * 修改请求任务
     *
     * @param dcsRequestTask 请求任务
     * @return 结果
     */
    public int updateDcsRequestTask(DcsRequestTask dcsRequestTask);

    /**
     * 删除请求任务
     *
     * @param requestId 请求任务主键
     * @return 结果
     */
    public int deleteDcsRequestTaskByRequestId(Long requestId);

    /**
     * 批量删除请求任务
     *
     * @param requestIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDcsRequestTaskByRequestIds(Long[] requestIds);
}
